﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using MCP2210;


namespace WindowsFormsApplication1
{
    

    public partial class MainForm : Form
    {
        //Variables
        const uint MCP2210_VID = 0x04D8;   // VID for Microchip Technology Inc.
        const uint MCP2210_PID = 0x00DE;   // PID for MCP2210
        
        const int GPIO = 0x00;
        const int CHIP_SELECT = 0x01;
        const int DEDICATED_FUNCTION = 0x02;
        
        
        bool isConnected = false;           // Connection status variable for MCP2210
        byte[] gpioPinDes; 



        MCP2210.DevIO UsbSpi;

        private short ea_dsp0801_translate(char my_char) {
	        short result = 0;
	
	        switch (my_char) {
                // C# doesn't have binary numbers, and it's much easier if you can see the bits. So...
		        case ' ': result = Convert.ToInt16("0000000000000000", 2); break;
		        case '0': result = Convert.ToInt16("0010010000111111", 2); break;
		        case '1': result = Convert.ToInt16("0000000000000110", 2); break;
		        case '2': result = Convert.ToInt16("0000000011011011", 2); break;
		        case '3': result = Convert.ToInt16("0000000010001111", 2); break;
		        case '4': result = Convert.ToInt16("0001001011100000", 2); break;
		        case '5': result = Convert.ToInt16("0000000011101101", 2); break;
		        case '6': result = Convert.ToInt16("0000000011111101", 2); break;
		        case '7': result = Convert.ToInt16("0000000000000111", 2); break;
		        case '8': result = Convert.ToInt16("0000000011111111", 2); break;
		        case '9': result = Convert.ToInt16("0000000011101111", 2); break;
		        case 'A': result = Convert.ToInt16("0000000011110111", 2); break;
		        case 'B': result = Convert.ToInt16("0001001010001111", 2); break;
		        case 'C': result = Convert.ToInt16("0000000000111001", 2); break;
		        case 'D': result = Convert.ToInt16("0001001000001111", 2); break;
		        case 'E': result = Convert.ToInt16("0000000001111001", 2); break;
		        case 'F': result = Convert.ToInt16("0000000001110001", 2); break;
		        case 'G': result = Convert.ToInt16("0000000010111101", 2); break;
		        case 'H': result = Convert.ToInt16("0000000011110110", 2); break;
		        case 'I': result = Convert.ToInt16("0001001000001001", 2); break;
		        case 'J': result = Convert.ToInt16("0000000000011110", 2); break;
		        case 'K': result = Convert.ToInt16("0000110001110000", 2); break;
		        case 'L': result = Convert.ToInt16("0000000000111000", 2); break;
		        case 'M': result = Convert.ToInt16("0000010100110110", 2); break;
		        case 'N': result = Convert.ToInt16("0000100100110110", 2); break;
		        case 'O': result = Convert.ToInt16("0000000000111111", 2); break;
		        case 'P': result = Convert.ToInt16("0000000011110011", 2); break;
		        case 'Q': result = Convert.ToInt16("0000100000111111", 2); break;
		        case 'R': result = Convert.ToInt16("0000100011110011", 2); break;
		        case 'S': result = Convert.ToInt16("0000000011101101", 2); break;
		        case 'T': result = Convert.ToInt16("0001001000000001", 2); break;
		        case 'U': result = Convert.ToInt16("0000000000111110", 2); break;
		        case 'V': result = Convert.ToInt16("0010010000110000", 2); break;
		        case 'W': result = Convert.ToInt16("0010100000110110", 2); break;
		        case 'X': result = Convert.ToInt16("0010110100000000", 2); break;
		        case 'Y': result = Convert.ToInt16("0001010100000000", 2); break;
		        case 'Z': result = Convert.ToInt16("0010010000001001", 2); break;
                case '*': result = Convert.ToInt16("0011111111000000", 2); break;
                default: result = 0; break;
	        }
	        return result;
        }
        
        public MainForm()
        {
            InitializeComponent();
        }

        private void button1_Click(object sender, EventArgs e)
        {
            int count;
            UsbSpi = new DevIO(MCP2210_VID, MCP2210_PID);

			isConnected = UsbSpi.Settings.GetConnectionStatus();
            if (isConnected) {
                label1.Text = "MCP2210 says hi";
                UsbSpi.Settings.SetSpiBitRate(DllConstants.CURRENT_SETTINGS_ONLY, 100000);
                gpioPinDes = new byte[10];

                UsbSpi.Settings.GetGpioPinDesignations(DllConstants.CURRENT_SETTINGS_ONLY, gpioPinDes);
                GPIO_label.Text = "";
                for (count = 0; count < 8; count++)
                {
                    GPIO_label.Text = GPIO_label.Text + gpioPinDes[count].ToString() + " ";
                }

                gpioPinDes[0] = GPIO;   // set to GPIO just in case it's not
                
                UsbSpi.Settings.SetGpioConfig(DllConstants.CURRENT_SETTINGS_ONLY, gpioPinDes, 0x00 /* default=0 */, 
                                                  0x00 /* dir = output */);
                UsbSpi.Settings.SetSpiMode(DllConstants.CURRENT_SETTINGS_ONLY, 1);

            } else {
                label1.Text = "Can't find MCP2210";
            }

        }

        private void send_data(Byte[] data)
        {
            int gpio_pin_vals;
            byte[] dataRx = new byte[16];

            gpio_pin_vals = UsbSpi.Functions.GetGpioPinVal();
            gpio_pin_vals = gpio_pin_vals & 0x1fe;  // set bit 0 = 0
            UsbSpi.Functions.SetGpioPinVal((ushort)gpio_pin_vals);

            UsbSpi.Settings.SetSpiTxferSize(DllConstants.CURRENT_SETTINGS_ONLY, 16);
            UsbSpi.Functions.TxferSpiData(data, dataRx);

            // do latch

            gpio_pin_vals = UsbSpi.Functions.GetGpioPinVal();
            gpio_pin_vals = gpio_pin_vals | 0x001;  // set bit 0 = 1
            UsbSpi.Functions.SetGpioPinVal((ushort)gpio_pin_vals);

            gpio_pin_vals = UsbSpi.Functions.GetGpioPinVal();
            gpio_pin_vals = gpio_pin_vals & 0x1fe;  // set bit 0 = 0
            UsbSpi.Functions.SetGpioPinVal((ushort)gpio_pin_vals);
        }

        private void button2_Click(object sender, EventArgs e)
        {
            byte[] dataTx = new byte[16];

            int count;
            for (count = 0; count < 16; count ++) {
                dataTx[count] = 0xff;
            }
            send_data(dataTx);


        }

        private void button3_Click(object sender, EventArgs e)
        {
            byte[] dataTx = new byte[16];

            int count;
            int max;
            short ledbits;

            max = textBox1.Text.Length;
            if (max > 16)
            {
                max = 16;
            }
            for (count = 0; count < 8; count ++) {
                if (count < max)
                {
                    ledbits = ea_dsp0801_translate(textBox1.Text.ToCharArray()[count]);
                    dataTx[count*2] = (byte)(ledbits >> 8);
                    dataTx[count * 2 + 1] = (byte)(ledbits & 0xff);
                }
                else
                {
                    dataTx[count * 2] = 0;
                    dataTx[count * 2 + 1] = 0;
                }
            }
            send_data(dataTx);

        }
    }
}
